@@ -1,7 +1,8 @@
 #' @export
-#' @title open a connexion to a 'PowerPoint' file
-#' @description read and import a pptx file as an R object
+#' @title Create a 'PowerPoint' document object
+#' @description Read and import a pptx file as an R object
 #' representing the document.
+#'
 #' The function is called `read_pptx` because it allows you to initialize an
 #' object of class `rpptx` from an existing PowerPoint file. Content will be
 #' added to the existing presentation. By default, an empty document is used.
@@ -50,6 +51,8 @@ read_pptx <- function( path = NULL ){
                                       master_xfrm = obj$masterLayouts$xfrm() )
 
   obj$slide <- dir_slide$new( package_dir, obj$slideLayouts$get_xfrm_data() )
+  obj$notesSlide <- dir_notesSlide$new(package_dir)
+  obj$notesMaster <- dir_notesMaster$new(package_dir, slide_master$new("ppt/notesMasters"))
   obj$content_type <- content_type$new( package_dir )
   obj$core_properties <- read_core_properties(package_dir)
 
@@ -71,9 +74,10 @@ read_table_style <- function(path){
              stringsAsFactors = FALSE )
 }
 
-#' write a 'PowerPoint' file.
-#'
-#'
+#' @title Write a 'PowerPoint' file.
+#' @description Write a 'PowerPoint' file
+#' with an object of class 'rpptx' (created with
+#' [read_pptx()]).
 #' @param x an rpptx object
 #' @param target path to the pptx file to write
 #' @param ... unused
@@ -105,6 +109,8 @@ print.rpptx <- function(x, target = NULL, ...){
 
   x$slide$save_slides()
 
+  x$notesSlide$save_slides()
+
   x$core_properties['modified','value'] <- format( Sys.time(), "%Y-%m-%dT%H:%M:%SZ")
   x$core_properties['lastModifiedBy','value'] <- Sys.getenv("USER")
   write_core_properties(x$core_properties, x$package_dir)
